@@ -805,6 +805,8 @@ class Witter():
             tweet = self.ui.getEntryText()
             #see if we have just an empty string (eg eroneous button press)
             if (tweet == ""):
+                note = osso.SystemNote(self.osso_c)
+                note.system_note_dialog("You must enter a message first")
                 print "No tweet to go with image"
                 return
 
@@ -831,6 +833,8 @@ class Witter():
             self.ui.setTweetText("")
             dialog.hide()
         except IOError:
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog("Failed to load selected image")
             print "couldn't read file"
         print file
 
@@ -1052,7 +1056,7 @@ class Witter():
                 shortUrl = bitlyapi.shorten(urlEntry.get_text())
                 #switch the long url in to the data
                 self.ui.appendTweetText(shortUrl)
-            except bitly.BitleyError:
+            except bitly.BitlyError:
                 print "bitly gave error response"
             except KeyError:
                 print "bitly gave key error response"
